@@ -1,5 +1,5 @@
 /*
- * $Id: acl.c,v 1.85.2.7 1997/03/26 07:29:32 wessels Exp $
+ * $Id: acl.c,v 1.85.2.10 1997/04/24 19:43:17 wessels Exp $
  *
  * DEBUG: section 28    Access Control
  * AUTHOR: Duane Wessels
@@ -236,16 +236,15 @@ aclParseMethodList(void *curlist)
 static int
 decode_addr(const char *asc, struct in_addr *addr, struct in_addr *mask)
 {
-    u_num32 a = 0;
+    u_num32 a;
     int a1 = 0, a2 = 0, a3 = 0, a4 = 0;
     struct hostent *hp = NULL;
 
     switch (sscanf(asc, "%d.%d.%d.%d", &a1, &a2, &a3, &a4)) {
     case 4:			/* a dotted quad */
-	if ((a = (u_num32) inet_addr(asc)) != inaddr_none ||
-	    !strcmp(asc, "255.255.255.255")) {
-	    addr->s_addr = a;
-	    /* inet_addr() outputs in network byte order */
+	if (!safe_inet_addr(asc, addr)) {
+	    debug(28, 0, "decode_addr: unsafe IP address: '%s'\n", asc);
+	    fatal("decode_addr: unsafe IP address");
 	}
 	break;
     case 1:			/* a significant bits value for a mask */
