@@ -1,6 +1,6 @@
 
 /*
- * $Id: client_side.c,v 1.90.2.14 1997/08/07 20:35:22 wessels Exp $
+ * $Id: client_side.c,v 1.90.2.15 1997/08/25 16:34:51 wessels Exp $
  *
  * DEBUG: section 33    Client-side Routines
  * AUTHOR: Duane Wessels
@@ -412,17 +412,20 @@ proxyAuthenticate(const char *headers)
     passwd++;
 
     /* See if we've already validated them */
+    passwd[0] |= 0x80;		/* check mutated password */
     if (strcmp(hashr->item, passwd) == 0) {
 	debug(33, 5, "proxyAuthenticate: user %s previously validated\n", sent_user);
 	xfree(clear_userandpw);
 	return sent_user;
     }
+    passwd[0] &= ~(0x80);	/* check vs crypt */
     if (strcmp(hashr->item, (char *) crypt(passwd, hashr->item))) {
 	/* Passwords differ, deny access */
 	debug(33, 4, "proxyAuthenticate: authentication failed: user %s passwords differ\n", sent_user);
 	xfree(clear_userandpw);
 	return (dash_str);
     }
+    passwd[0] |= 0x80;		/* store mutated password away */
     debug(33, 5, "proxyAuthenticate: user %s validated\n", sent_user);
     hash_delete(validated, sent_user);
     hash_insert(validated, xstrdup(sent_user), (void *) xstrdup(passwd));
